pub struct SwitchCase {
breaks: bool,
value: Vec<u8>,
fields: Vec<DCField>,
}Expand description
Represents a case in a DC switch declaration.
Fields
breaks: boolNote that in the legacy DC language, switch cases always assume to break, no matter if a break statement was parsed at syntax analysis. This legacy behavior is not followed by Donet.
value: Vec<u8>Empty byte array signifies default case.
fields: Vec<DCField>Implementations
Sourceimpl<'dc> SwitchCase
impl<'dc> SwitchCase
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns true if this case is a default case.
Sourcepub fn get_num_fields(&self) -> usize
pub fn get_num_fields(&self) -> usize
Returns the number of fields in the case.
pub fn get_field(&self, index: usize) -> Option<&DCField>
pub fn get_field_by_name(&self, _name: String) -> Option<&DCField>